@@ -36,8 +36,9 @@ Glib::RefPtr<Gtk::Action> BacklinkAction::create(const sigc::slot<void, Gtk::Men
 }
 
 BacklinkAction::BacklinkAction(const sigc::slot<void, Gtk::Menu*> & slot)
-  : Gtk::Action("BacklinkAction", Gtk::Stock::JUMP_TO,
-                _("What links here?"), _("Which notes have links to here?"))
+  : gnote::NoteWindow::NonModifyingAction("BacklinkAction", Gtk::Stock::JUMP_TO,
+                                          _("What links here?"),
+                                          _("Which notes have links to here?"))
   , m_update_menu_slot(slot)
 {
 }
@@ -96,7 +97,9 @@ void BacklinkMenuItem::on_activate()
     return;
   }
 
-  gnote::MainWindow::present_in_new_window(m_note, true);
+  gnote::MainWindow::present_in_new_window(m_note,
+    gnote::Preferences::obj().get_schema_settings(gnote::Preferences::SCHEMA_GNOTE)->
+      get_boolean(gnote::Preferences::ENABLE_CLOSE_NOTE_ON_ESCAPE));
 }
 
 
