@@ -36,36 +36,6 @@ NoteDirectoryWatcherModule::NoteDirectoryWatcherModule()
   ADD_INTERFACE_IMPL(NoteDirectoryWatcherApplicationAddin);
 }
 
-const char * NoteDirectoryWatcherModule::id() const
-{
-  return "NoteDirectoryWatcherAddin";
-}
-
-const char * NoteDirectoryWatcherModule::name() const
-{
-  return _("Note Directory Watcher");
-}
-
-const char * NoteDirectoryWatcherModule::description() const
-{
-  return _("Watch your Gnote note directory for changes to your notes.");
-}
-
-const char * NoteDirectoryWatcherModule::authors() const
-{
-  return _("Aurimas Černius and Tomboy original authors");
-}
-
-int NoteDirectoryWatcherModule::category() const
-{
-  return gnote::ADDIN_CATEGORY_TOOLS;
-}
-
-const char * NoteDirectoryWatcherModule::version() const
-{
-  return "0.1";
-}
-
 
 
 
@@ -251,7 +221,8 @@ void NoteDirectoryWatcherApplicationAddin::add_or_update_note(const std::string
     reader.close();
   }
   catch(std::ios::failure & e) {
-    ERR_OUT("NoteDirectoryWatcher: Update aborted, error reading %s: %s", note_path.c_str(), e.what());
+    /* TRANSLATORS: first %s is file name, second is error */
+    ERR_OUT(_("NoteDirectoryWatcher: Update aborted, error reading %s: %s"), note_path.c_str(), e.what());
     return;
   }
 
@@ -277,19 +248,22 @@ void NoteDirectoryWatcherApplicationAddin::add_or_update_note(const std::string
       title = match_info.fetch(1);
     }
     else {
-      ERR_OUT("NoteDirectoryWatcher: Error reading note title from %s", note_path.c_str());
+      /* TRANSLATORS: %s is file */
+      ERR_OUT(_("NoteDirectoryWatcher: Error reading note title from %s"), note_path.c_str());
       return;
     }
 
     try {
       note = note_manager().create_with_guid(title, note_id);
       if(note == 0) {
-        ERR_OUT("NoteDirectoryWatcher: Unknown error creating note from %s", note_path.c_str());
+        /* TRANSLATORS: %s is file */
+        ERR_OUT(_("NoteDirectoryWatcher: Unknown error creating note from %s"), note_path.c_str());
         return;
       }
     }
     catch(std::exception & e) {
-      ERR_OUT("NoteDirectoryWatcher: Error creating note from %s: %s", note_path.c_str(), e.what());
+      /* TRANSLATORS: first %s is file, second is error */
+      ERR_OUT(_("NoteDirectoryWatcher: Error creating note from %s: %s"), note_path.c_str(), e.what());
       return;
     }
   }
@@ -301,7 +275,8 @@ void NoteDirectoryWatcherApplicationAddin::add_or_update_note(const std::string
     note->load_foreign_note_xml(noteXml, gnote::CONTENT_CHANGED);
   }
   catch(std::exception & e) {
-    ERR_OUT("NoteDirectoryWatcher: Update aborted, error parsing %s: %s", note_path.c_str(), e.what());
+    /* TRANSLATORS: first %s is file, second is error */
+    ERR_OUT(_("NoteDirectoryWatcher: Update aborted, error parsing %s: %s"), note_path.c_str(), e.what());
     if(is_new_note) {
       note_manager().delete_note(note);
     }
