@@ -1,7 +1,7 @@
 /*
  * gnote
  *
- * Copyright (C) 2012 Aurimas Cernius
+ * Copyright (C) 2012-2013 Aurimas Cernius
  * Copyright (C) 2009 Hubert Figuiere
  *
  * This program is free software: you can redistribute it and/or modify
@@ -44,9 +44,9 @@ namespace gnote {
   void NoteAddin::dispose(bool disposing)
   {
     if (disposing) {
-      for(std::list<Gtk::MenuItem*>::const_iterator iter = m_tools_menu_items.begin();
-          iter != m_tools_menu_items.end(); ++iter) {
-        delete *iter;
+      for(std::list<std::string>::const_iterator iter = m_note_actions.begin();
+          iter != m_note_actions.end(); ++iter) {
+        get_window()->remove_widget_action(*iter);
       }
       for(std::list<Gtk::MenuItem*>::const_iterator iter = m_text_menu_items.begin();
           iter != m_text_menu_items.end(); ++iter) {
@@ -70,14 +70,6 @@ namespace gnote {
     on_note_opened();
     NoteWindow * window = get_window();
 
-    for(std::list<Gtk::MenuItem*>::const_iterator iter = m_tools_menu_items.begin();
-        iter != m_tools_menu_items.end(); ++iter) {
-      Gtk::Widget *item= *iter;
-      if ((item->get_parent() == NULL) ||
-          (item->get_parent() != window->plugin_menu()))
-        window->plugin_menu()->add (*item);
-    }
-
     for(std::list<Gtk::MenuItem*>::const_iterator iter = m_text_menu_items.begin();
         iter != m_text_menu_items.end(); ++iter) {
       Gtk::Widget *item = *iter;
@@ -91,25 +83,24 @@ namespace gnote {
     for(ToolItemMap::const_iterator iter = m_toolbar_items.begin();
         iter != m_toolbar_items.end(); ++iter) {
       if ((iter->first->get_parent() == NULL) ||
-          (iter->first->get_parent() != window->toolbar())) {
-        window->toolbar()->insert (*(iter->first), iter->second);
+          (iter->first->get_parent() != window->embeddable_toolbar())) {
+        Gtk::Grid *grid = window->embeddable_toolbar();
+        int col = grid->get_children().size();
+        grid->attach(*(iter->first), col, 0, 1, 1);
       }
     }
   }
 
-
-  void NoteAddin::add_plugin_menu_item (Gtk::MenuItem *item)
+  void NoteAddin::add_note_action(const Glib::RefPtr<Gtk::Action> & action, int order)
   {
-    if (is_disposing())
-      throw sharp::Exception ("Plugin is disposing already");
-
-    m_tools_menu_items.push_back (item);
-
-    if (m_note->is_opened()) {
-      get_window()->plugin_menu()->add (*item);
+    if(is_disposing()) {
+      throw sharp::Exception("Plugin is disposing already");
     }
+
+    m_note_actions.push_back(action->get_name());
+    get_window()->add_widget_action(action, order);
   }
-    
+
   void NoteAddin::add_tool_item (Gtk::ToolItem *item, int position)
   {
     if (is_disposing())
@@ -118,7 +109,8 @@ namespace gnote {
     m_toolbar_items [item] = position;
       
     if (m_note->is_opened()) {
-      get_window()->toolbar()->insert (*item, position);
+      Gtk::Grid *grid = get_window()->embeddable_toolbar();
+      grid->attach(*item, grid->get_children().size(), 0, 1, 1);
     }
   }
 
