@@ -25,7 +25,6 @@
 
 #include <set>
 #include <string>
-#include <tr1/memory>
 
 #include "base/macros.hpp"
 #include "tag.hpp"
@@ -39,10 +38,10 @@ namespace notebooks {
 /// An object that represents a notebook in Tomboy
 /// </summary>
 class Notebook 
-  : public std::tr1::enable_shared_from_this<Notebook>
+  : public enable_shared_from_this<Notebook>
 {
 public:
-  typedef std::tr1::shared_ptr<Notebook> Ptr;
+  typedef shared_ptr<Notebook> Ptr;
   static const char * NOTEBOOK_TAG_PREFIX;
   Notebook(NoteManager &, const std::string &, bool is_special = false);
   Notebook(NoteManager &, const Tag::Ptr &);
@@ -54,7 +53,7 @@ public:
   Note::Ptr find_template_note() const;
   virtual Note::Ptr   get_template_note() const;
   Note::Ptr create_notebook_note();
-  virtual bool contains_note(const Note::Ptr &);
+  virtual bool contains_note(const Note::Ptr & note, bool include_system = false);
   virtual bool add_note(const Note::Ptr &);
   virtual Glib::RefPtr<Gdk::Pixbuf> get_icon();
   static std::string normalize(const std::string & s);
@@ -62,8 +61,13 @@ public:
   virtual ~Notebook()
     {}
 protected:
+  static Tag::Ptr template_tag();
+  static bool is_template_note(const Note::Ptr &);
+
   NoteManager & m_note_manager;
 private:
+  static Tag::Ptr s_template_tag;
+
   Notebook(const Notebook &);
   Notebook & operator=(const Notebook &);
   std::string m_name;
@@ -83,7 +87,7 @@ class SpecialNotebook
   : public Notebook
 {
 public:
-  typedef std::tr1::shared_ptr<SpecialNotebook> Ptr;
+  typedef shared_ptr<SpecialNotebook> Ptr;
 protected:
   SpecialNotebook(NoteManager & m, const std::string &s)
     : Notebook(m, s, true)
@@ -104,10 +108,10 @@ class AllNotesNotebook
   : public SpecialNotebook
 {
 public:
-  typedef std::tr1::shared_ptr<AllNotesNotebook> Ptr;
+  typedef shared_ptr<AllNotesNotebook> Ptr;
   AllNotesNotebook(NoteManager &);
   virtual std::string get_normalized_name() const override;
-  virtual bool        contains_note(const Note::Ptr &) override;
+  virtual bool        contains_note(const Note::Ptr & note, bool include_system = false) override;
   virtual bool        add_note(const Note::Ptr &) override;
   virtual Glib::RefPtr<Gdk::Pixbuf> get_icon() override;
 };
@@ -122,10 +126,10 @@ class UnfiledNotesNotebook
   : public SpecialNotebook
 {
 public:
-  typedef std::tr1::shared_ptr<UnfiledNotesNotebook> Ptr;
+  typedef shared_ptr<UnfiledNotesNotebook> Ptr;
   UnfiledNotesNotebook(NoteManager &);
   virtual std::string get_normalized_name() const override;
-  virtual bool        contains_note(const Note::Ptr &) override;
+  virtual bool        contains_note(const Note::Ptr & note, bool include_system = false) override;
   virtual bool        add_note(const Note::Ptr &) override;
   virtual Glib::RefPtr<Gdk::Pixbuf> get_icon() override;
 };
@@ -135,10 +139,10 @@ class PinnedNotesNotebook
   : public SpecialNotebook
 {
 public:
-  typedef std::tr1::shared_ptr<PinnedNotesNotebook> Ptr;
+  typedef shared_ptr<PinnedNotesNotebook> Ptr;
   PinnedNotesNotebook(NoteManager &);
   virtual std::string get_normalized_name() const override;
-  virtual bool        contains_note(const Note::Ptr &) override;
+  virtual bool        contains_note(const Note::Ptr & note, bool include_system = false) override;
   virtual bool        add_note(const Note::Ptr &) override;
   virtual Glib::RefPtr<Gdk::Pixbuf> get_icon() override;
 };
@@ -148,10 +152,10 @@ class ActiveNotesNotebook
   : public SpecialNotebook
 {
 public:
-  typedef std::tr1::shared_ptr<ActiveNotesNotebook> Ptr;
+  typedef shared_ptr<ActiveNotesNotebook> Ptr;
   ActiveNotesNotebook(NoteManager &);
   virtual std::string get_normalized_name() const override;
-  virtual bool        contains_note(const Note::Ptr &) override;
+  virtual bool        contains_note(const Note::Ptr & note, bool include_system = false) override;
   virtual bool        add_note(const Note::Ptr &) override;
   virtual Glib::RefPtr<Gdk::Pixbuf> get_icon() override;
   bool empty();
