@@ -71,7 +71,7 @@ namespace gnote {
 
      iter = m_notebooks->append();
      iter->set_value(0, m_active_notes);
-     std::tr1::static_pointer_cast<ActiveNotesNotebook>(m_active_notes)->signal_size_changed
+     static_pointer_cast<ActiveNotesNotebook>(m_active_notes)->signal_size_changed
        .connect(sigc::mem_fun(*this, &NotebookManager::on_active_notes_size_changed));
 
       
@@ -154,6 +154,18 @@ namespace gnote {
       return notebook;
     }
 
+    bool NotebookManager::add_notebook(const Notebook::Ptr & notebook)
+    {
+      if(m_notebookMap.find(notebook->get_normalized_name()) != m_notebookMap.end()) {
+        return false;
+      }
+
+      Gtk::TreeIter iter = m_notebooks->append();
+      iter->set_value(0, notebook);
+      m_notebookMap[notebook->get_normalized_name()] = iter;
+      return true;
+    }
+
     void NotebookManager::delete_notebook(const Notebook::Ptr & notebook)
     {
       if (!notebook)
@@ -177,10 +189,11 @@ namespace gnote {
         
         // Remove the notebook tag from every note that's in the notebook
         std::list<Note *> notes;
-        notebook->get_tag()->get_notes(notes);
-        for(std::list<Note *>::const_iterator note_iter = notes.begin();
-            note_iter != notes.end(); ++note_iter) {
-          Note * note = *note_iter;
+        Tag::Ptr tag = notebook->get_tag();
+        if(tag) {
+          tag->get_notes(notes);
+        }
+        FOREACH(Note *note, notes) {
           note->remove_tag (notebook->get_tag());
           m_note_removed_from_notebook (*note, notebook);
         }
@@ -425,8 +438,8 @@ namespace gnote {
       if (!notebook_a || !notebook_b)
         return 0;
 
-      SpecialNotebook::Ptr spec_a = std::tr1::dynamic_pointer_cast<SpecialNotebook>(notebook_a);
-      SpecialNotebook::Ptr spec_b = std::tr1::dynamic_pointer_cast<SpecialNotebook>(notebook_b);
+      SpecialNotebook::Ptr spec_a = dynamic_pointer_cast<SpecialNotebook>(notebook_a);
+      SpecialNotebook::Ptr spec_b = dynamic_pointer_cast<SpecialNotebook>(notebook_b);
       if(spec_a != 0 && spec_b != 0) {
         return strcmp(spec_a->get_normalized_name().c_str(), spec_b->get_normalized_name().c_str());
       }
@@ -477,7 +490,7 @@ namespace gnote {
     {
       Notebook::Ptr notebook;
       iter->get_value(0, notebook);
-      if (!notebook || std::tr1::dynamic_pointer_cast<SpecialNotebook>(notebook)) {
+      if (!notebook || dynamic_pointer_cast<SpecialNotebook>(notebook)) {
         return false;
       }
       return true;
@@ -488,7 +501,7 @@ namespace gnote {
       Notebook::Ptr notebook;
       iter->get_value(0, notebook);
       if(notebook == m_active_notes) {
-        return !std::tr1::static_pointer_cast<ActiveNotesNotebook>(m_active_notes)->empty();
+        return !static_pointer_cast<ActiveNotesNotebook>(m_active_notes)->empty();
       }
 
       return true;
