@@ -73,7 +73,7 @@ namespace gnote {
       
       Notebook::Ptr destNotebook;
       iter->get_value(0, destNotebook);
-      if (std::tr1::dynamic_pointer_cast<AllNotesNotebook>(destNotebook)) {
+      if(dynamic_pointer_cast<AllNotesNotebook>(destNotebook)) {
         context->drag_finish (false, false, time_);
         return;
       }
@@ -111,7 +111,7 @@ namespace gnote {
       
       Notebook::Ptr destNotebook;
       iter->get_value(0, destNotebook);
-      if (std::tr1::dynamic_pointer_cast<AllNotesNotebook>(destNotebook)) {
+      if(dynamic_pointer_cast<AllNotesNotebook>(destNotebook)) {
         gtk_tree_view_set_drag_dest_row (gobj(), NULL, GTK_TREE_VIEW_DROP_INTO_OR_AFTER);
         return true;
       }
