@@ -1,7 +1,7 @@
 /*
  * gnote
  *
- * Copyright (C) 2011-2012 Aurimas Cernius
+ * Copyright (C) 2011-2013 Aurimas Cernius
  * Copyright (C) 2009 Hubert Figuiere
  *
  * This program is free software: you can redistribute it and/or modify
@@ -58,13 +58,13 @@ namespace gnote {
 
     static const char *NOTE_RENAME_BEHAVIOR;
     static const char *USE_STATUS_ICON;
+    static const char *OPEN_NOTES_IN_NEW_WINDOW;
 
     static const char *MAIN_WINDOW_MAXIMIZED;
-    static const char *SEARCH_WINDOW_X_POS;
-    static const char *SEARCH_WINDOW_Y_POS;
     static const char *SEARCH_WINDOW_WIDTH;
     static const char *SEARCH_WINDOW_HEIGHT;
     static const char *SEARCH_WINDOW_SPLITTER_POS;
+    static const char *SEARCH_SORTING;
 
     static const char *KEYBINDING_SHOW_NOTE_MENU;
     static const char *KEYBINDING_OPEN_START_HERE;
@@ -83,6 +83,7 @@ namespace gnote {
     static const char *SYNC_FUSE_WDFS_URL;
     static const char *SYNC_FUSE_WDFS_USERNAME;
 
+    static const char *DESKTOP_GNOME_CLOCK_FORMAT;
     static const char *DESKTOP_GNOME_FONT;
     static const char *DESKTOP_GNOME_KEY_THEME;
 
