@@ -1,7 +1,7 @@
 /*
  * gnote
  *
- * Copyright (C) 2011 Aurimas Cernius
+ * Copyright (C) 2011-2012 Aurimas Cernius
  * Copyright (C) 2011 Debarshi Ray
  * Copyright (C) 2009 Hubert Figuiere
  * 
@@ -26,6 +26,7 @@
 
 
 
+#include <glib/gstdio.h>
 #include <glibmm.h>
 
 #include "sharp/directory.hpp"
@@ -59,6 +60,24 @@ namespace sharp {
     }
   }
 
+  void directory_get_directories(const std::string & dir,
+                                 std::list<std::string>  & files)
+  {
+    if(!Glib::file_test(dir, Glib::FILE_TEST_EXISTS | Glib::FILE_TEST_IS_DIR)) {
+      return;
+    }
+
+    Glib::Dir d(dir);
+
+    for(Glib::Dir::iterator iter = d.begin(); iter != d.end(); ++iter) {
+      const std::string file(dir + "/" + *iter);
+
+      if(Glib::file_test(file, Glib::FILE_TEST_IS_DIR)) {
+        files.push_back(file);
+      }
+    }
+  }
+
   void directory_get_files(const std::string & dir, std::list<std::string>  & files)
   {
     directory_get_files_with_ext(dir, "", files);
@@ -112,4 +131,17 @@ namespace sharp {
     return Gio::File::create_for_path(dir)->make_directory_with_parents();
   }
 
+  bool directory_delete(const std::string & dir, bool recursive)
+  {
+    if(!recursive) {
+      std::list<std::string> files;
+      directory_get_files(dir, files);
+      if(files.size()) {
+        return false;
+      }
+    }
+
+    return g_remove(dir.c_str()) == 0;
+  }
+
 }
