@@ -1,7 +1,7 @@
 /*
  * gnote
  *
- * Copyright (C) 2012 Aurimas Cernius
+ * Copyright (C) 2012-2013 Aurimas Cernius
  *
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -107,6 +107,10 @@ namespace sync {
 
   const char *SyncUtils::common_paths[] = {"/sbin", "/bin", "/usr/bin"};
 
+  //instance
+  SyncUtils SyncUtils::s_obj;
+
+
   bool SyncUtils::is_fuse_enabled()
   {
     try {
