@@ -281,10 +281,19 @@ namespace gnote {
                           modifiers,
                           flags);
       foo->show ();
-
+      foo->set_sensitive(m_fake_menu.get_sensitive());
       m_fake_menu.append (*foo);
     }
 
+    void GlobalKeybinder::enabled(bool enable)
+    {
+      m_fake_menu.set_sensitive(enable);
+      std::vector<Gtk::Widget*> items = m_fake_menu.get_children();
+      FOREACH(Gtk::Widget *item, items) {
+        item->set_sensitive(enable);
+      }
+    }
+
 
     HIGMessageDialog::HIGMessageDialog(Gtk::Window *parent,
                                        GtkDialogFlags flags, Gtk::MessageType msg_type, 
@@ -345,21 +354,20 @@ namespace gnote {
       label_vbox->set_hexpand(true);
       hbox->attach(*label_vbox, hbox_col++, 0, 1, 1);
 
-      std::string title = str(boost::format("<span weight='bold' size='larger'>%1%"
-                                            "</span>\n") % header.c_str());
-
-      Gtk::Label *label;
-
-      label = manage(new Gtk::Label (title));
-      label->set_use_markup(true);
-      label->set_justify(Gtk::JUSTIFY_LEFT);
-      label->set_line_wrap(true);
-      label->set_alignment (0.0f, 0.5f);
-      label->show();
-      label_vbox->attach(*label, 0, label_vbox_row++, 1, 1);
+      if(header != "") {
+        std::string title = str(boost::format("<span weight='bold' size='larger'>%1%"
+                                              "</span>\n") % header.c_str());
+        Gtk::Label *label = manage(new Gtk::Label (title));
+        label->set_use_markup(true);
+        label->set_justify(Gtk::JUSTIFY_LEFT);
+        label->set_line_wrap(true);
+        label->set_alignment (0.0f, 0.5f);
+        label->show();
+        label_vbox->attach(*label, 0, label_vbox_row++, 1, 1);
+      }
 
       if(msg != "") {
-        label = manage(new Gtk::Label(msg));
+        Gtk::Label *label = manage(new Gtk::Label(msg));
         label->set_use_markup(true);
         label->set_justify(Gtk::JUSTIFY_LEFT);
         label->set_line_wrap(true);
