@@ -79,7 +79,11 @@ namespace gnote {
 
       void add_accelerator(const sigc::slot<void> & , guint, Gdk::ModifierType, 
                            Gtk::AccelFlags);
-      
+      void enabled(bool enable);
+      bool enabled() const
+        {
+          return m_fake_menu.get_sensitive();
+        }
     private:
       Glib::RefPtr<Gtk::AccelGroup> m_accel_group;
       Gtk::Menu m_fake_menu;
@@ -91,8 +95,8 @@ namespace gnote {
     {
     public:
       HIGMessageDialog(Gtk::Window *, GtkDialogFlags flags, Gtk::MessageType msg_type, 
-                       Gtk::ButtonsType btn_type, const Glib::ustring & header,
-                       const Glib::ustring & msg);
+                       Gtk::ButtonsType btn_type, const Glib::ustring & header = Glib::ustring(),
+                       const Glib::ustring & msg = Glib::ustring());
       void add_button(const Gtk::BuiltinStockID& stock_id, 
                        Gtk::ResponseType response, bool is_default);
       void add_button(const Glib::RefPtr<Gdk::Pixbuf> & pixbuf, 
