@@ -26,6 +26,7 @@
 
 #include <string.h>
 
+#include <boost/bind.hpp>
 #include <boost/format.hpp>
 
 #include <glibmm/i18n.h>
@@ -309,7 +310,7 @@ namespace gnote {
     }
 
     m_tag_applied_cid = get_buffer()->signal_apply_tag().connect(
-      sigc::mem_fun(*this, &NoteSpellChecker::tag_applied));
+      sigc::mem_fun(*this, &NoteSpellChecker::tag_applied), false);  // connect before
 
     if (!m_obj_ptr) {
       m_obj_ptr = gtk_spell_checker_new();
@@ -360,7 +361,8 @@ namespace gnote {
         const Glib::RefPtr<const Gtk::TextTag>& atag(*tag_iter);
         if ((tag != atag) &&
             !NoteTagTable::tag_is_spell_checkable (atag)) {
-          remove = true;
+          // cancel attempt to add misspelled tag on non-spell-check place
+          get_buffer()->signal_apply_tag().emission_stop();
           break;
         }
       }
@@ -370,6 +372,7 @@ namespace gnote {
     }
 
     if (remove) {
+      // adding non-spell-check tag on misspelled text, remove the spell-check first
       get_buffer()->remove_tag_by_name("gtkspell-misspelled",
                                start_char, end_char);
     }
@@ -787,10 +790,21 @@ namespace gnote {
     DBG_OUT ("Matching Note title '%s' at %d-%d...",
              hit.key().c_str(), hit.start(), hit.end());
 
-    get_buffer()->remove_tag (m_broken_link_tag, title_start, title_end);
+    get_note()->get_tag_table()->foreach(
+      boost::bind(sigc::mem_fun(*this, &NoteLinkWatcher::remove_link_tag),
+                  _1, title_start, title_end));
     get_buffer()->apply_tag (m_link_tag, title_start, title_end);
   }
 
+  void NoteLinkWatcher::remove_link_tag(const Glib::RefPtr<Gtk::TextTag> & tag,
+                                        const Gtk::TextIter & start, const Gtk::TextIter & end)
+  {
+    NoteTag::Ptr note_tag = NoteTag::Ptr::cast_dynamic(tag);
+    if (note_tag && note_tag->can_activate()) {
+      get_buffer()->remove_tag(note_tag, start, end);
+    }
+  }
+
   void NoteLinkWatcher::highlight_note_in_block (const Note::Ptr & find_note, 
                                                  const Gtk::TextIter & start,
                                                  const Gtk::TextIter & end)
@@ -863,9 +877,11 @@ namespace gnote {
   }
 
 
-  void NoteLinkWatcher::on_apply_tag(const Glib::RefPtr<Gtk::TextBuffer::Tag> & /*tag*/,
+  void NoteLinkWatcher::on_apply_tag(const Glib::RefPtr<Gtk::TextBuffer::Tag> & tag,
                                      const Gtk::TextIter & start, const Gtk::TextIter &end)
   {
+    if (tag->property_name() != get_note()->get_tag_table()->get_link_tag()->property_name())
+      return;
     std::string link_name = start.get_text (end);
     Note::Ptr link = manager().find (link_name);
     if(!link)
